@@ -18,7 +18,7 @@ use Readonly;
 use Data::Walk;
 use Try::Tiny;
 
-our $VERSION = 1.08;
+our $VERSION = 1.09;
 
 our $override;
 my $JSON_OBJ = Cpanel::JSON::XS->new()->utf8->pretty();
@@ -188,6 +188,7 @@ sub _override_dbi_execute {
             }
             catch {
                 my $error = $_;
+
                 # say STDERR $error;
             };
 
@@ -199,7 +200,7 @@ sub _override_dbi_execute {
             };
 
             my $result = [];
-            if ( $sql =~ m/^INSERT|^UPDATE|^DELETE/i ) {
+            if ( $sql =~ m/^INSERT|^UPDATE|^DELETE/i && $retval ) {
                 push @$result, ['rows'];
                 foreach my $row ( 1 .. $rows ) {
                     push @{$result}, [];
@@ -211,6 +212,12 @@ sub _override_dbi_execute {
               if ref $self->{bind_params}
               && scalar @{ $self->{bind_params} } > 0;
 
+            # query failed:
+            if ( !$retval ) {
+                $query_data->{failure} = [ 5, 'Ooops!' ];
+                $query_data->{results} = undef;
+            }
+
             push @{ $self->{result} }, $query_data
               if $sql !~ m/BEGIN|COMMIT/;
             $self->_write_to_file();
@@ -702,11 +709,6 @@ sub _process_mock_data {
     my ( $self, $data ) = @_;
 
     while ( my ( $index, $row ) = each( @{$data} ) ) {
-        if ( $row->{statement} eq "ROLLBACK" ) {
-            $data->[ $index - 1 ]->{err}     = 1062;
-            $data->[ $index - 1 ]->{results} = undef;
-            $data->[ $index - 1 ]->{errstr}  = 'Rollback kicked in';
-        }
 
         if ( $row->{col_names} ) {
             my $cols = delete $row->{col_names};
@@ -714,7 +716,6 @@ sub _process_mock_data {
         }
     }
 
-    # say Dumper $data;
     return $self;
 }
 
